# HACON
Lots of cyber security tool
# Install
```
pip3 install HACON
```
# Using
```python
from hacon import HACON

HACON.arguments("-h")
```

# With docker
## Install 
```
docker pull ghcr.io/onuratakan/hacon:latest
```
## Using
```
docker run -it --network=host ghcr.io/onuratakan/hacon
```

# Reminder
Important Information and Reminder Information and programs in all repositories are created for testing purposes. Any legal responsibility belongs to the person or organization that uses it.
